## Semi-automatic Analysis as annotation

Linguistic research into the Hebrew Bible has not ended. The meaning of
Hebrew verb forms in poetry is a long standing problem (and many
occurrences in prose are far from clear for that matter), and
data-driven research has the potential to produce new solutions \cite{Kalkman2015}.
Verb meanings are also dependent on the number and nature of
constituents in the sentence (verbal valence), and it is worthwhile to
devise a flow chart system to generate verb senses on the basis of
signals near verb occurrences \cite{Dyk2014}. This involves a lot of
trial and error. Sometimes it leads to a review of the linguistic
encoding, to new syntactic and semantic distinctions. One way to
organize this, is to generate the results of a flow chart as a set of
annotations to be presented next to the text. The researcher can then
see the decisions in full context, and comment on those outcomes by
manual annotations. These annotations can be harvested in turn
and provide a basis for an improved algorithm. This
workflow is supported on SHEBANQ, although not many people are fully
utilizing it yet.

Experience, however, shows that it is cumbersome to execute this work
exclusively on a website. A website such as SHEBANQ only supports that
many use cases, while every research activity requires its own data
preprocessing. An efficient workflow for this kind of research is to
collect data, store it in spreadsheets, have the researcher work on them,
and then feed the filled-in sheets back into the system. We support this
workflow by means of [LAF-Fabric](https://github.com/ETCBC/laf-fabric), which is an off-line companion to
SHEBANQ, based on exactly the same data. With the help of LAF-Fabric, the programming scholar can
grab all data
that is needed for a particular task, lay it out neatly in columns, and
convert edited sheets into new sets of annotations. See \cite{Roorda2015a}
for initial examples. The work of verbal valency is available on
the [SHEBANQ tools page](https://shebanq.ancient-data.org/tools?goto=valence). These new annotations have been bulk-imported
into SHEBANQ and pubished, but htey can also serve as basis for new algorithms in LAF-Fabric.

Another, even more
computationally intensive, example is the [quest for parallel passages](https://shebanq.ancient-data.org/shebanq/static/docs/tools/parallel/parallels.html) in the Bible. 
This is part of the
[Syntactic Variation project](http://www.nwo.nl/en/research-and-results/research-projects/i/30/9930.html),
carried out by a team of (PhD) researchers
at the ETCBC. To see what is at stake here, see \cite{Rezetko2016}.

Indeed, using LAF-Fabric requires programming skills. It is a Python
package that gives streamlined access to the Hebrew Text Database. A
beginner’s course in Python is enough to get started.